Index: /trunk/src/VBox/Main/src-client/GuestProcessImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/GuestProcessImpl.cpp	(revision 84648)
+++ /trunk/src/VBox/Main/src-client/GuestProcessImpl.cpp	(revision 84649)
@@ -2661,5 +2661,5 @@
         default:
             strErr = Utf8StrFmt(Guest::tr("Unhandled error %Rrc for \"%s\" occurred for tool \"%s\" on guest -- please file a bug report"),
-                                guestErrorInfo.getRc(), guestErrorInfo.getWhat(), pszTool);
+                                guestErrorInfo.getRc(), guestErrorInfo.getWhat().c_str(), pszTool);
             break;
     }
Index: /trunk/src/VBox/Main/src-client/GuestSessionImplTasks.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/GuestSessionImplTasks.cpp	(revision 84648)
+++ /trunk/src/VBox/Main/src-client/GuestSessionImplTasks.cpp	(revision 84649)
@@ -459,11 +459,11 @@
  *
  * @return VBox status code. VINF_NO_CHANGE if file was skipped.
  * @param  strSource            Full path of source file on the guest to copy.
  * @param  strDest              Full destination path and file name (host style) to copy file to.
  * @param  fFileCopyFlags       File copy flags.
  */
-int GuestSessionTask::fileCopyFromGuest(const Utf8Str &strSrc, const Utf8Str &strDest, FileCopyFlag_T fFileCopyFlags)
-{
-    LogFlowThisFunc(("strSource=%s, strDest=%s, enmFileCopyFlags=0x%x\n", strSrc.c_str(), strDest.c_str(), fFileCopyFlags));
+int GuestSessionTask::fileCopyFromGuest(const Utf8Str &strSrc, const Utf8Str &strDst, FileCopyFlag_T fFileCopyFlags)
+{
+    LogFlowThisFunc(("strSource=%s, strDest=%s, enmFileCopyFlags=0x%x\n", strSrc.c_str(), strDst.c_str(), fFileCopyFlags));
 
     GuestFileOpenInfo srcOpenInfo;
@@ -537,5 +537,5 @@
     if (RT_SUCCESS(rc))
     {
-        rc = RTPathQueryInfo(strDest.c_str(), &dstObjInfo, RTFSOBJATTRADD_NOTHING);
+        rc = RTPathQueryInfo(strDst.c_str(), &dstObjInfo, RTFSOBJATTRADD_NOTHING);
         if (RT_SUCCESS(rc))
         {
@@ -543,5 +543,5 @@
             {
                 setProgressErrorMsg(VBOX_E_IPRT_ERROR,
-                                    Utf8StrFmt(GuestSession::tr("Host file \"%s\" already exists"), strDest.c_str()));
+                                    Utf8StrFmt(GuestSession::tr("Host file \"%s\" already exists"), strDst.c_str()));
                 rc = VERR_ALREADY_EXISTS;
             }
@@ -555,5 +555,5 @@
                     setProgressErrorMsg(VBOX_E_IPRT_ERROR,
                                         Utf8StrFmt(GuestSession::tr("Host file \"%s\" has same or newer modification date"),
-                                                   strDest.c_str()));
+                                                   strDst.c_str()));
                     fSkip = true;
                 }
@@ -565,5 +565,5 @@
                 setProgressErrorMsg(VBOX_E_IPRT_ERROR,
                                     Utf8StrFmt(GuestSession::tr("Host file lookup for \"%s\" failed: %Rrc"),
-                                               strDest.c_str(), rc));
+                                               strDst.c_str(), rc));
         }
     }
@@ -583,9 +583,9 @@
             {
                 setProgressErrorMsg(VBOX_E_IPRT_ERROR,
-                                    Utf8StrFmt(GuestSession::tr("Host file \"%s\" already exists"), strDest.c_str()));
+                                    Utf8StrFmt(GuestSession::tr("Host file \"%s\" already exists"), strDst.c_str()));
                 rc = VERR_ALREADY_EXISTS;
             }
             else
-                pszDstFile = RTStrDup(strDest.c_str());
+                pszDstFile = RTStrDup(strDst.c_str());
         }
         else if (RTFS_IS_DIRECTORY(dstObjInfo.Attr.fMode))
@@ -593,8 +593,8 @@
             /* Build the final file name with destination path (on the host). */
             char szDstPath[RTPATH_MAX];
-            RTStrPrintf2(szDstPath, sizeof(szDstPath), "%s", strDest.c_str());
-
-            if (   !strDest.endsWith("\\")
-                && !strDest.endsWith("/"))
+            RTStrPrintf2(szDstPath, sizeof(szDstPath), "%s", strDst.c_str());
+
+            if (   !strDst.endsWith("\\")
+                && !strDst.endsWith("/"))
                 RTPathAppend(szDstPath, sizeof(szDstPath), "/"); /* IPRT can handle / on all hosts. */
 
@@ -609,9 +609,9 @@
                 setProgressErrorMsg(VBOX_E_IPRT_ERROR,
                                     Utf8StrFmt(GuestSession::tr("Host file \"%s\" is a symbolic link"),
-                                               strDest.c_str()));
+                                               strDst.c_str()));
                 rc = VERR_IS_A_SYMLINK;
             }
             else
-                pszDstFile = RTStrDup(strDest.c_str());
+                pszDstFile = RTStrDup(strDst.c_str());
         }
         else
@@ -622,5 +622,5 @@
     }
     else if (rc == VERR_FILE_NOT_FOUND)
-        pszDstFile = RTStrDup(strDest.c_str());
+        pszDstFile = RTStrDup(strDst.c_str());
 
     if (   RT_SUCCESS(rc)
@@ -2579,10 +2579,10 @@
                             if (itFiles->fFlags & ISOFILE_FLAG_OPTIONAL)
                                 fOptional = true;
-                            rc = copyFileToGuest(pSession, hVfsIso, itFiles->strSource, itFiles->strDest, fOptional);
+                            rc = copyFileToGuest(pSession, hVfsIso, itFiles->strSource, itFiles->strDst, fOptional);
                             if (RT_FAILURE(rc))
                             {
                                 hr = setProgressErrorMsg(VBOX_E_IPRT_ERROR,
                                                          Utf8StrFmt(GuestSession::tr("Error while copying file \"%s\" to \"%s\" on the guest: %Rrc"),
-                                                                    itFiles->strSource.c_str(), itFiles->strDest.c_str(), rc));
+                                                                    itFiles->strSource.c_str(), itFiles->strDst.c_str(), rc));
                                 break;
                             }
@@ -459,11 +459,11 @@
  *
  * @return VBox status code. VINF_NO_CHANGE if file was skipped.
- * @param  strSource            Full path of source file on the guest to copy.
- * @param  strDest              Full destination path and file name (host style) to copy file to.
+ * @param  strSrc               Full path of source file on the guest to copy.
+ * @param  strDst               Full destination path and file name (host style) to copy file to.
  * @param  fFileCopyFlags       File copy flags.
  */
